@@ -74,7 +74,9 @@ LbsArray* lbs_array_copy (LbsArray* dest, const LbsArray* src) {
 
     dest->len = src->len;
     dest->free_func = src->free_func;
-    memcpy (dest->data, src->data, src->size * src->len);
+    if (src->data != NULL && dest->data != NULL) {
+        memcpy (dest->data, src->data, src->size * src->len);
+    }
     return dest;
 }
 
@@ -98,17 +100,14 @@ LbsArray* lbs_array_cat (LbsArray* dest, const LbsArray* more) {
 
 void* lbs_array_ref_generic (void* array_generic) {
     LbsArray* array = LBS_ARRAY (array_generic);
-    int oldref = array->ref_count;
-    int newref = oldref + 1;
-    if (newref <= oldref) {
-        return NULL;
-    }
-
-    array->ref_count = newref;
+    array->ref_count++;
     return array;
 }
 
 void lbs_array_unref_generic (void* array_generic) {
+    if (array_generic == NULL) {
+        return;
+    }
     LbsArray* array = LBS_ARRAY (array_generic);
     array->ref_count--;
     if (array->ref_count <= 0) {
@@ -117,9 +116,12 @@ void lbs_array_unref_generic (void* array_generic) {
 }
 
 void lbs_array_free_generic (void* array_generic) {
+    if (array_generic == NULL) {
+        return;
+    }
     LbsArray* array = LBS_ARRAY (array_generic);
     if (array->free_func != NULL) {
-        int i = 0;
+        size_t i = 0;
         char* d = array->data;
         for (; i < array->len; i++, d += array->size) {
             (*(array->free_func)) (*((void**)d));
