@@ -32,17 +32,14 @@ void lbs_array2_copy_out (LbsArray2* array2, void* copy_out) {
 
 void* lbs_array2_ref_generic (void* array2_generic) {
     LbsArray2* array2 = LBS_ARRAY2 (array2_generic);
-    int oldref = array2->ref_count;
-    int newref = oldref + 1;
-    if (newref <= oldref) {
-        return NULL;
-    }
-
-    array2->ref_count = newref;
+    array2->ref_count++;
     return array2;
 }
 
 void lbs_array2_unref_generic (void* array2_generic) {
+    if (array2_generic == NULL) {
+        return;
+    }
     LbsArray2* array2 = LBS_ARRAY2 (array2_generic);
     array2->ref_count--;
     if (array2->ref_count <= 0) {
